# @hidoo/gulp-task-build-css-sass

> Task that build css by sass for gulp.

## Installation

```sh
$ npm install --save-dev gulp @hidoo/gulp-task-build-css-sass
```

## Usage

basic:

```js
import { task } from 'gulp';
import buildCss from '@hidoo/gulp-task-build-css-sass';

task(
  'css',
  buildCss({
    src: '/path/to/scss/main.scss',
    dest: '/path/to/dest'
  })
);
```

remove unused CSS:

```js
import { task } from 'gulp';
import buildCss from '@hidoo/gulp-task-build-css-scss';

task(
  'css',
  buildCss({
    src: '/path/to/scss/main.scss',
    dest: '/path/to/dest',
    uncssTargets: ['/path/to/target.html']
  })
);
```

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### csso

### autoprefixer

### cssmqpacker

### defaultOptions

Default options.

Type: [Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)

#### name

#### src

#### dest

#### filename

#### suffix

#### banner

#### sassOptions

#### postcssPlugins

#### compress

#### verbose

### buildCss

Return css build task by sass

#### Parameters

- `options` **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** options (optional, default `{}`)

  - `options.name` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** task name (use as displayName) (optional, default `'build:css'`)
  - `options.src` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** source path
  - `options.dest` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** destination path
  - `options.filename` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** destination filename (optional, default `'main.css'`)
  - `options.suffix` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** suffix when compressed (optional, default `'.min'`)
  - `options.targets` **[Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array)<[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>** target browsers.
  - `options.browsers` **[Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array)<[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>** alias of options.targets.
  - `options.banner` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** license comments (optional, default `''`)
  - `options.postcssPlugins` **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** list of PostCSS plugin. (optional, default `[]`)
  - `options.verbose` **[Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** out debug log or not (optional, default `false`)

#### Examples

```javascript
import { task } from 'gulp';
import buildCss, { autoprefixer } from '@hidoo/gulp-task-build-css-sass';

task(
  'css',
  buildCss({
    name: 'css:main',
    src: '/path/to/scss/main.scss',
    dest: '/path/to/dest',
    filename: 'styles.css',
    suffix: '.hoge',
    targets: ['> 0.1% in JP'],
    banner: '/*! copyright <%= pkg.author %> * /\n',
    sassOptions: { outputStyle: 'nested' },
    postcssPlugins: [autoprefixer(), (root) => root],
    compress: true
  })
);
```

Returns **[Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function)\<Transform>**&#x20;

## Test

```sh
$ npm test
```

## License

MIT
